==> tengits_widgets-0.0.1.tar.gz: lib/card/src/widgets/operator_card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_widgets/tengits_widgets.dart';

class TLOperatorCard extends StatefulWidget {
  const TLOperatorCard({
    Key? key,
    this.title,
    this.subTitle,
    this.operatorCardStyle = const TLOperatorCardStyle(),
    this.operatorCardBuilders = const TLOperatorCardBuilders(),
    this.operatorCardEvent = const TLOperatorCardEvent(),
  }) : super(key: key);

  /// 标题文本
  final String? title;

  /// 子标题文本
  final String? subTitle;

  /// 风格配置
  final TLOperatorCardStyle operatorCardStyle;

  /// 自定义Builders集
  final TLOperatorCardBuilders operatorCardBuilders;

  /// Builders集 手势事件
  final TLOperatorCardEvent operatorCardEvent;

  @override
  State<TLOperatorCard> createState() => _TLOperatorCardState();
}

class _TLOperatorCardState extends State<TLOperatorCard> {
  ///
  late String? _title;
  late String? _subTitle;
  late TLOperatorCardStyle _operatorCardStyle;
  late TLOperatorCardBuilders _operatorCardBuilders;
  late TLOperatorCardEvent _operatorCardEvent;

  @override
  void initState() {
    ///
    _title = widget.title;

    ///
    _subTitle = widget.subTitle;

    ///
    _operatorCardStyle = widget.operatorCardStyle;

    ///
    _operatorCardBuilders = widget.operatorCardBuilders;

    ///
    _operatorCardEvent = widget.operatorCardEvent;

    super.initState();
  }

  @override
  void didUpdateWidget(TLOperatorCard oldWidget) {
    ///
    if (oldWidget.title != widget.title) {
      ///
      _title = widget.title;
    }

    ///
    if (oldWidget.subTitle != widget.subTitle) {
      ///
      _subTitle = widget.subTitle;
    }

    ///
    if (oldWidget.operatorCardStyle != widget.operatorCardStyle) {
      ///
      _operatorCardStyle = widget.operatorCardStyle;
    }

    ///
    if (oldWidget.operatorCardBuilders != widget.operatorCardBuilders) {
      ///
      _operatorCardBuilders = widget.operatorCardBuilders;
    }

    ///
    if (oldWidget.operatorCardEvent != widget.operatorCardEvent) {
      ///
      _operatorCardEvent = widget.operatorCardEvent;
    }

    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: _operatorCardEvent.onTap,
      child: Card(
        color: Colors.white, // 背景色
        shadowColor: Colors.transparent, // 阴影颜色
        elevation: 0.0, // 阴影高度
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8.r)), // 边框
        borderOnForeground: false, // 是否在 child 前绘制 border，默认为 true
        margin: EdgeInsets.only(bottom: 16.h), // 外边距
        clipBehavior: Clip.hardEdge, // 剪切模式
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: 12.h),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Container(
                alignment: Alignment.topLeft,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: EdgeInsets.only(right: 6.w),
                      child: Visibility(
                        visible: _operatorCardStyle.showLalelImage,
                        child: Image(
                          image: ImageUtils.getAssetImage("assets/images/path.png", package: "tengits_common"),
                          width: 7.w,
                          height: 23.h,
                          fit: BoxFit.fill,
                        ),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.only(right: _operatorCardStyle.isRequire || _operatorCardStyle.showLalelImage ? 8.w : 14.w),
                      child: Visibility(
                        visible: _operatorCardStyle.isRequire,
                        child: Text('*', style: TextStyle(color: Colors.red, fontSize: 16.sp)),
                      ),
                    ),
                    Expanded(
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onTitleContentTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.titleContent?.call(context) ??
                              RichText(
                                text: TextSpan(
                                  text: _title,
                                  style: _operatorCardStyle.titleStyle ??
                                      TextStyle(
                                        color: const Color(0xFF323233),
                                        fontSize: 16.sp,
                                        fontWeight: FontWeight.w500,
                                        height: 1.5,
                                      ),
                                  children: [
                                    TextSpan(
                                      text: _subTitle,
                                      style: _operatorCardStyle.subTitleStyle ??
                                          TextStyle(
                                            color: Colors.black,
                                            fontSize: 12.sp,
                                            fontWeight: FontWeight.w400,
                                            height: 1.5,
                                          ),
                                    ),
                                  ],
                                ),
                                textAlign: TextAlign.left,
                                softWrap: true,
                                overflow: TextOverflow.ellipsis,
                                maxLines: _operatorCardStyle.titleTextMaxLines,
                              ),
                        ),
                      ),
                    ),
                    Visibility(
                      visible: _operatorCardStyle.showLeading && _operatorCardBuilders.leading?.call(context) != null,
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onLeadingTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.leading?.call(context),
                        ),
                      ),
                    ),
                    Visibility(
                      visible: _operatorCardStyle.showTrailing,
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onTrailingTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.trailing?.call(context) ??
                              Padding(
                                padding: EdgeInsets.only(top: 5.h),
                                child: _operatorCardStyle.trailingIcon ??
                                    Icon(
                                      _operatorCardStyle.trailingIconData ?? Icons.keyboard_arrow_right,
                                      color: _operatorCardStyle.trailingIconColor,
                                      size: 16.r,
                                    ),
                              ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 8.w,
                    ),
                  ],
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showLabelContent && _operatorCardBuilders.labelContent?.call(context) != null,
                child: GestureDetector(
                  onTap: _operatorCardEvent.onLabelContentTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 16.w, top: 8.h, right: 16.w),
                    child: _operatorCardBuilders.labelContent?.call(context),
                  ),
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showDivider && _operatorCardStyle.showContent && _operatorCardBuilders.content?.call(context) != null,
                child: Divider(
                  height: 24.h,
                  thickness: 1.h,
                  color: _operatorCardStyle.dividerColor,
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showContent && _operatorCardBuilders.content?.call(context) != null,
                child: GestureDetector(
                  onTap: _operatorCardEvent.onContentTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 16.w, top: 8.h, right: 16.w, bottom: 8.h),
                    child: _operatorCardBuilders.content?.call(context),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> tengits_widgets-0.0.4.tar.gz: lib/card/src/widgets/operator_card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_widgets/tengits_widgets.dart';

class TLOperatorCard extends StatefulWidget {
  const TLOperatorCard({
    Key? key,
    this.title,
    this.subTitle,
    this.operatorCardStyle = const TLOperatorCardStyle(),
    this.operatorCardBuilders = const TLOperatorCardBuilders(),
    this.operatorCardEvent = const TLOperatorCardEvent(),
  }) : super(key: key);

  /// 标题文本
  final String? title;

  /// 子标题文本
  final String? subTitle;

  /// 风格配置
  final TLOperatorCardStyle operatorCardStyle;

  /// 自定义Builders集
  final TLOperatorCardBuilders operatorCardBuilders;

  /// Builders集 手势事件
  final TLOperatorCardEvent operatorCardEvent;

  @override
  State<TLOperatorCard> createState() => _TLOperatorCardState();
}

class _TLOperatorCardState extends State<TLOperatorCard> {
  ///
  late String? _title;
  late String? _subTitle;
  late TLOperatorCardStyle _operatorCardStyle;
  late TLOperatorCardBuilders _operatorCardBuilders;
  late TLOperatorCardEvent _operatorCardEvent;

  @override
  void initState() {
    ///
    _title = widget.title;

    ///
    _subTitle = widget.subTitle;

    ///
    _operatorCardStyle = widget.operatorCardStyle;

    ///
    _operatorCardBuilders = widget.operatorCardBuilders;

    ///
    _operatorCardEvent = widget.operatorCardEvent;

    super.initState();
  }

  @override
  void didUpdateWidget(TLOperatorCard oldWidget) {
    ///
    if (oldWidget.title != widget.title) {
      ///
      _title = widget.title;
    }

    ///
    if (oldWidget.subTitle != widget.subTitle) {
      ///
      _subTitle = widget.subTitle;
    }

    ///
    if (oldWidget.operatorCardStyle != widget.operatorCardStyle) {
      ///
      _operatorCardStyle = widget.operatorCardStyle;
    }

    ///
    if (oldWidget.operatorCardBuilders != widget.operatorCardBuilders) {
      ///
      _operatorCardBuilders = widget.operatorCardBuilders;
    }

    ///
    if (oldWidget.operatorCardEvent != widget.operatorCardEvent) {
      ///
      _operatorCardEvent = widget.operatorCardEvent;
    }

    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: _operatorCardEvent.onTap,
      child: Card(
        color: Colors.white, // 背景色
        shadowColor: Colors.transparent, // 阴影颜色
        elevation: 0.0, // 阴影高度
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8.r)), // 边框
        borderOnForeground: false, // 是否在 child 前绘制 border，默认为 true
        margin: EdgeInsets.only(bottom: 16.h), // 外边距
        clipBehavior: Clip.hardEdge, // 剪切模式
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: 12.h),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Container(
                alignment: Alignment.topLeft,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: EdgeInsets.only(right: 6.w),
                      child: Visibility(
                        visible: _operatorCardStyle.showLalelImage,
                        child: Image(
                          image: ImageUtils.getAssetImageProvider("assets/images/path.png", package: "tengits_common"),
                          width: 7.w,
                          height: 23.h,
                          fit: BoxFit.fill,
                        ),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.only(right: _operatorCardStyle.isRequire || _operatorCardStyle.showLalelImage ? 8.w : 14.w),
                      child: Visibility(
                        visible: _operatorCardStyle.isRequire,
                        child: Text('*', style: TextStyle(color: Colors.red, fontSize: 16.sp)),
                      ),
                    ),
                    Expanded(
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onTitleContentTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.titleContent?.call(context) ??
                              RichText(
                                text: TextSpan(
                                  text: _title,
                                  style: _operatorCardStyle.titleStyle ??
                                      TextStyle(
                                        color: const Color(0xFF323233),
                                        fontSize: 16.sp,
                                        fontWeight: FontWeight.w500,
                                        height: 1.5,
                                      ),
                                  children: [
                                    TextSpan(
                                      text: _subTitle,
                                      style: _operatorCardStyle.subTitleStyle ??
                                          TextStyle(
                                            color: Colors.black,
                                            fontSize: 12.sp,
                                            fontWeight: FontWeight.w400,
                                            height: 1.5,
                                          ),
                                    ),
                                  ],
                                ),
                                textAlign: TextAlign.left,
                                softWrap: true,
                                overflow: TextOverflow.ellipsis,
                                maxLines: _operatorCardStyle.titleTextMaxLines,
                              ),
                        ),
                      ),
                    ),
                    Visibility(
                      visible: _operatorCardStyle.showLeading && _operatorCardBuilders.leading?.call(context) != null,
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onLeadingTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.leading?.call(context),
                        ),
                      ),
                    ),
                    Visibility(
                      visible: _operatorCardStyle.showTrailing,
                      child: GestureDetector(
                        onTap: _operatorCardEvent.onTrailingTap,
                        child: Padding(
                          padding: EdgeInsets.only(right: 8.w),
                          child: _operatorCardBuilders.trailing?.call(context) ??
                              Padding(
                                padding: EdgeInsets.only(top: 5.h),
                                child: _operatorCardStyle.trailingIcon ??
                                    Icon(
                                      _operatorCardStyle.trailingIconData ?? Icons.keyboard_arrow_right,
                                      color: _operatorCardStyle.trailingIconColor,
                                      size: 16.r,
                                    ),
                              ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 8.w,
                    ),
                  ],
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showLabelContent && _operatorCardBuilders.labelContent?.call(context) != null,
                child: GestureDetector(
                  onTap: _operatorCardEvent.onLabelContentTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 16.w, top: 8.h, right: 16.w),
                    child: _operatorCardBuilders.labelContent?.call(context),
                  ),
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showDivider && _operatorCardStyle.showContent && _operatorCardBuilders.content?.call(context) != null,
                child: Divider(
                  height: 24.h,
                  thickness: 1.h,
                  color: _operatorCardStyle.dividerColor,
                ),
              ),
              Visibility(
                visible: _operatorCardStyle.showContent && _operatorCardBuilders.content?.call(context) != null,
                child: GestureDetector(
                  onTap: _operatorCardEvent.onContentTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 16.w, top: 8.h, right: 16.w, bottom: 8.h),
                    child: _operatorCardBuilders.content?.call(context),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
